@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20130131';
+our $VERSION = '0.20130228';
 
-# Table last modified: 2013-01-31
+# Table last modified: 2013-02-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -27,7 +27,7 @@ our %ZIP_TABLE = (
     '020' => '(?:(?:8(?:5(?:2[0-35]|3[0-3]|8[04-68]|0[12578]|1[0-358]|6[0167]|7[0357]|5[013578]|4[034])|6(?:33|41|5[045]|7[278]|2[02]|6[167]|1[0-2]|8[68]|0[1256])|794)|0(?:1(?:8[0-578]|9[2368])|59[2356]|49[356])))',
     '021' => '(?:8(?:5(?:11|44|55|77|0[1-46]|6[67])|6(?:04|11|33|87)))',
     '022' => '(?:8(?:5(?:12|0[1-578])|602))',
-    '023' => '(?:(?:049[23]|850[12]|1192))',
+    '023' => '(?:(?:049[23]|1192|8501))',
     '024' => '(?:(?:8(?:5(?:20|0[157]|1[0138])|650)|0(?:19[2-5]|392)))',
     '025' => '(?:(?:039[2-5]|860[12]))',
     '026' => '(?:8(?:5(?:50|67)|686))',
@@ -106,9 +106,9 @@ our %ZIP_TABLE = (
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|5(?:6[0-2568]|4[2-5]|8[1568]|1[0-2459]|7[6-9]|5[2489]|0[1-46-9]|3[0-5]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|2(?:0[1-4]|1[035])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[035-7]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|2[245]|1[125689])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|3[0-8]|8[457]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|1[02-79]|3[0-57-9]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
+    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|8[2457]|7[02358]|3[0-8]|2[124589]|5[0-25689])|4(?:4[348]|7[0-3]|2[2-7]|0[1-57]|1[02-79]|3[0-57-9]|6[0-24-6]|8[01467]|5[016])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|3[035689]|4[0468]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|8[0368]|2[014589]|5[167]|7[27]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[257-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
+    '105' => '(?:(?:8(?:4(?:3[2-79]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457]|1[0-24-69])|5(?:4[035689]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:01|22|1[0-35]|3[038])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|1[458]|3[0-25]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:8[13589]|2[0-2578]|5[0-26-8]|4[356]|3[02]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|50|8[06]|2[023578]|6[6-8]|1[15-79]|0[14]|7[46]|3[0-3689])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|6[067]|4[08])|3(?:55|4[028]|3[0-2568]|7[013]|2[0346]|6[09]|8[048])|0(?:06|60|77)))',
     '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|0[1-35-79]|6[124-8]|4[03-578]|5[0-35-9]|2[035]|1[0258]|8[0-3568])|3(?:1[1357]|0[357]|8[0134689]|7[0-37-9]|5[0158]|4[15]|3[013489]|2[0-35689]|6[016])|4(?:85|0[347]|6[67]|5[16]|2[013-5]|3[029]|1[0-24-7]|7[0478]|4[48])|2(?:7[05-8]|8[02]|0[1-38]|3[0-4]|5[05]|1[017]|[24][0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
@@ -121,7 +121,7 @@ our %ZIP_TABLE = (
     '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-26]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
     '120' => '(?:8(?:5(?:44|81|7[057]|0[178]|1[02]|2[068]|3[0469]|5[03568])|60[12]))',
-    '121' => '(?:8(?:5(?:33|40|0[245]|2[0-4]|8[58]|5[05]|1[01])|6(?:[02]1|3[39]|8[0-2]|1[016])|7(?:01|29|1[01])|080))',
+    '121' => '(?:8(?:5(?:33|40|1[015]|0[245]|2[0-4]|8[58]|5[05])|6(?:[02]1|3[39]|8[0-2]|1[016])|7(?:01|29|1[01])|080))',
     '123' => '(?:85(?:40|8[58]|1[147]|0[135689]))',
     '124' => '(?:8(?:5(?:77|6[06]|1[018]|3[3589]|0[1-39]|8[58]|5[05]|2[024])|070))',
     '125' => '(?:8(?:5(?:55|88|1[1-57]|0[3-8]|2[026])|601))',
@@ -134,7 +134,7 @@ our %ZIP_TABLE = (
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:90|8[03]|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[02-46-8]|0[2-6]|7[0-36]|8[01346-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|6[0-25-8]|5[05-79]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
+    '141' => '(?:8(?:6(?:[23][0137-9]|4[02-46-8]|0[2-6]|7[0-36]|8[01346-8]|5[035-8]|1[013568]|6[024-68])|5(?:2[0-2569]|4[04]|8[02-48]|0[13-578]|1[024579]|3[03-5]|6[0-25-8]|5[05-79]|7[1256])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|5[02578]|3[13589]|0[24-8]|8[05]|6[04578]|4[014]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[14]|6[01])))',
@@ -149,7 +149,7 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:22|33|55|0[1246]|8[58]|1[01])|666))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
     '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:30|1[0-259]|4[379]|8[0-35-9]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:1[015]|4[47]|3[013]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
+    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|2[1457]|3[013-68]|7[457])|5(?:1[0-259]|4[379]|8[0-35-9]|2[0-249]|[36][05]|5[57]|7[157]|0[15])|4(?:1[015]|4[47]|3[013]|7[27]|2[0-39]|5[01]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|2[0158]|7[05]|5[236-8]|4[015-7]|1[01])|710))',
     '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:1[25]|4[013]|7[57]|2[279]|5[16-8]|8[0357]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
     '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:7[056]|5[37-9]|6[069])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[13])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|6[156]|5[35])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|7[127]|3[89]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
@@ -202,7 +202,7 @@ our %ZIP_TABLE = (
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:[36]0|09|42|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:85(?:[56]6|22|70|1[0-249]|0[12]))',
-    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|78|8[06]|0[149]|1[1-6]|2[02]|6[08])|7(?:11|22|65)|080))',
+    '220' => '(?:8(?:5(?:58|77|1[015]|3[69]|2[0-3]|8[058]|0[12]|4[0-2]|6[56])|6(?:53|78|0[149]|1[1-6]|2[02]|6[08]|8[046])|7(?:11|22|65)|080))',
     '221' => '(?:8(?:5(?:[46]0|37|88|1[17]|5[058]|2[023])|7(?:12|41|65|0[1-35])|6(?:11|23|66|8[68])))',
     '222' => '(?:8(?:5(?:77|3[03]|8[056]|6[1-6]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:8(?:5(?:1[025]|2[0-356]|[58][058]|7[27]|6[067]|4[0-2]|0[125-8]|3[039])|68[67]))',
@@ -217,7 +217,7 @@ our %ZIP_TABLE = (
     '235' => '(?:85(?:[58]8|2[23]|0[15]))',
     '236' => '(?:8(?:5(?:15|0[1-4]|5[05])|6(?:48|53)))',
     '237' => '(?:85(?:23|55|8[58]|1[05]))',
-    '238' => '(?:(?:8(?:5(?:8[058]|1[013]|2[02]|3[35]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
+    '238' => '(?:(?:8(?:5(?:8[058]|3[356]|1[013]|2[02]|6[57]|5[08]|4[01])|6[18]6)|029[28]))',
     '239' => '(?:8(?:5(?:01|28|50|8[58])|68[68]))',
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0|15)|612)|019[2-8]))',
     '241' => '(?:8(?:5(?:15|0[12])|606))',
@@ -239,8 +239,8 @@ our %ZIP_TABLE = (
     '257' => '(?:8(?:5(?:11|33|55|66|2[23]|0[12]|8[4-68])|686))',
     '258' => '(?:(?:85(?:11|85|3[38]|0[168])|0195))',
     '259' => '(?:(?:1(?:1(?:8[58]|9[235-8])|29[23]|39[26])|0(?:19[2-46-8]|39[2356])))',
-    '260' => '(?:8(?:6(?:2[0-24-79]|0[13-7]|5[46]|4[2578]|1[0-3689]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|2[134]|8[0568]|7[257]|3[2458]|1[0-68]|0[1-35-9]|5[0-24-9]|6[02-7])|7(?:3[03]|1[02357]|2[02]|0[1-37])))',
-    '261' => '(?:8(?:5(?:66|75|3[03]|5[245]|4[45]|1[235]|2[0-2]|8[126-8]|0[1-378])|6(?:09|86)|733))',
+    '260' => '(?:8(?:6(?:0[13467]|2[0-24-79]|5[46]|4[2578]|1[0-3689]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|2[134]|8[0568]|7[257]|3[2458]|1[0-68]|0[1-35-9]|5[0-24-9]|6[02-7])|7(?:3[03]|1[02357]|2[02]|0[1-37])))',
+    '261' => '(?:8(?:5(?:66|75|3[03]|5[245]|4[45]|1[235]|2[0-2]|0[1-378]|8[125-8])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:36|55|0[2-468]|1[0-2])|7(?:10|33)))',
     '263' => '(?:8(?:5(?:[12]2|33|77|8[58]|5[05]|0[56])|733))',
     '264' => '(?:8(?:5(?:[35]0|8[25]|0[15])|6(?:04|46)|733))',
@@ -383,7 +383,7 @@ our %ZIP_TABLE = (
     '407' => '(?:(?:85(?:[01]1|49|55)|0192))',
     '408' => '(?:(?:85(?:22|33|85|5[05]|1[15])|01(?:88|92)))',
     '409' => '(?:(?:3(?:8(?:9[2-8]|8[01357-9])|39[23]|79[23]|293|692)|2(?:19[2-6]|59[2378]|398|992)|1(?:298|392)|019[2358]))',
-    '410' => '(?:(?:8(?:5(?:67|0[148]|2[025]|5[0-258]|8[058]|4[03-5]|3[0135]|7[05]|1[0145])|6(?:10|8[69]|5[45]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:19[2-6]|39[2-6])|0(?:39[568]|19[25])|3(?:29[23]|69[36])))',
+    '410' => '(?:(?:8(?:5(?:67|0[148]|2[025]|5[0-258]|8[058]|4[03-5]|3[0135]|7[05]|1[0145])|6(?:10|8[69]|5[45]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:19[2-7]|39[2-6])|0(?:39[568]|19[25])|3(?:29[23]|69[36])))',
     '411' => '(?:8(?:5(?:02|33|60|77|88|2[05]|5[15]|[14][01])|6(?:30|89|2[03]|4[148]|6[068]|5[0-2]|1[01])|7(?:[45]0|[78]7|2[025]|3[01])))',
     '412' => '(?:8(?:5(?:24|50|85|1[1-3]|0[15])|6(?:3[04]|0[159])))',
     '413' => '(?:(?:8(?:5(?:30|8[59]|0[25]|5[058]|6[067]|1[01])|6(?:26|78|1[18]))|0(?:29[238]|49[23]|196)))',
@@ -417,7 +417,7 @@ our %ZIP_TABLE = (
     '443' => '(?:(?:8(?:5(?:55|88)|6[01]1)|019[2-4]))',
     '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-25-7]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:85|1[01]|0[1-35])|60[12]))',
-    '446' => '(?:8(?:5(?:40|1[12478]|3[35]|0[1-8]|[58][58]|2[02-6])|6(?:35|41|86|0[12])))',
+    '446' => '(?:8(?:5(?:40|1[12478]|5[058]|3[35]|0[1-8]|8[58]|2[02-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
     '448' => '(?:8(?:6(?:10|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:31|50|2[35]|0[16])|731))',
     '449' => '(?:029[2-4])',
@@ -479,7 +479,7 @@ our %ZIP_TABLE = (
     '507' => '(?:8(?:5(?:[16]1|33|2[237])|6(?:50|0[1-3578])|70[1-3568]))',
     '508' => '(?:(?:8(?:5(?:[58]5|11|0[0-2])|6(?:[68]6|11))|0(?:292|494)))',
     '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|69[235]|19[23]|492)|0(?:29[24578]|19[278]|393|492)|2(?:59[2358]|29[235])|5(?:19[2358]|292|494)|9(?:29[23568]|19[25])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
-    '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[3-6]|2[025]|8[058]|1[0-25]|7[57]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
+    '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[3-6]|8[058]|1[0-25]|7[57]|2[0258]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
     '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-6]|19[28]|59[23]|492)|1192))',
     '512' => '(?:85(?:12|38|50))',
     '513' => '(?:8(?:6(?:[57]0|01|8[06]|3[0-3]|6[016])|5(?:[1-3]0|0[15])|701))',
@@ -612,7 +612,7 @@ our %ZIP_TABLE = (
     '648' => '(?:(?:0(?:2(?:8\d|9[2-8])|198|392)|85(?:41|85)))',
     '649' => '(?:(?:6(?:49[2-4]|59[235]|[126]92)|(?:[04]1|35)92|219[2358]|719[245]))',
     '650' => '(?:8(?:5(?:43|1[015]|5[01589]|2[0-258]|6[057]|3[0369]|7[015-7]|8[04-689]|0[1-35])|6(?:[68][06]|7[07])|7(?:87|94)))',
-    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[078]|9[4-7])|49[24])|01(?:7[0-2578]|9[35]|8[1578])|1195))',
+    '651' => '(?:(?:8(?:5(?:[58]5|01|67|1[124]|7[05]|2[56])|798)|2(?:1(?:8[078]|9[4-7])|49[24])|01(?:9[35]|8[1578]|7[01578])|1195))',
     '652' => '(?:85(?:[17]0|01|85|5[05]))',
     '653' => '(?:85(?:70|85))',
     '654' => '(?:(?:85(?:70|85)|019[2358]))',
@@ -858,7 +858,7 @@ our %ZIP_TABLE = (
     '899' => '(?:(?:5(?:29[2-4]|69[348]|19[23]|49[25]|392)|6(?:49[2-5]|19[23]|29[23]|592)|(?:3[14]|7[146]|8[16])92|2(?:59[2-6]|[127]92)|4(?:39[2-6]|[12]92)|0(?:29[23578]|492)|1(?:395|498|696)))',
     '900' => '(?:8(?:5(?:4[03-57]|5\d|2[02457]|0[13-57]|6[07]|3[013-5]|7[01578]|8[01568]|1[0-467])|6(?:10|66|78|5[0146]|0[1-59]|8[68])|7(?:[01]1|35|9[4-7])))',
     '901' => '(?:(?:2(?:5(?:40|88|97|6[0679]|0[1268]|1[0-25]|5[0-35-9]|3[014]|2[0156])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[25])|0(?:49[2-6]|29[2-5]|19[2-4]|39[23]|592|695)|3(?:[679]92|19[23]|59[25]|496|895)|1(?:19[2356]|39[23]|[24]92|595)))',
-    '902' => '(?:85(?:21|8[58]|5[05]|[17][01]))',
+    '902' => '(?:85(?:21|8[58]|5[05]|1[0-2]|7[01]))',
     '903' => '(?:(?:02(?:20|1[013-578]|0[13-7])|860[1-3]))',
     '904' => '(?:(?:0(?:49[2-6]|19[2-5]|39[2-5]|29[35])|2(?:19[2-6]|39[2-4]|29[23])|1(?:29[2-4]|[13]92)|85(?:[01]1|85)))',
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
@@ -887,7 +887,7 @@ our %ZIP_TABLE = (
     '930' => '(?:(?:8(?:5(?:4[03-58]|6[0-35-7]|3[0-35-9]|2[0-256]|0[124-9]|8[0135-9]|1[0-35-8]|7[013578]|5[024-68])|6(?:5[06]|0[3-5]|4[24]|3[067]|1[01]|8[016]|6[06-8])|798)|0(?:19[3-68]|39[3-57]|29[238])|1(?:29[258]|392)|2198))',
     '931' => '(?:8(?:5(?:33|62|2[23]|4[03]|7[17]|0[128]|[58][58]|1[0157])|6(?:01|88)))',
     '932' => '(?:(?:8(?:5(?:33|40|75|1[0-258]|5[0158]|6[27]|8[58]|0[1-358]|2[0258])|611)|0(?:39[23568]|19[38]|29[28])))',
-    '933' => '(?:(?:8(?:5(?:4[03]|0[1268]|6[367]|8[58]|1[01568]|3[0-3578]|5[08]|2[035-8])|6(?:[28]8|66|0[1-356]|1[01])|7(?:77|88))|0(?:39[235-7]|19[235]|29[235])))',
+    '933' => '(?:(?:8(?:5(?:4[03]|6[367]|8[58]|1[01568]|0[126-8]|3[0-3578]|5[08]|2[035-8])|6(?:[28]8|66|0[1-356]|1[01])|7(?:77|88))|0(?:39[235-7]|19[235]|29[235])))',
     '934' => '(?:8(?:5(?:22|77|6[78]|3[14]|[58][058]|0[12]|1[15])|6(?:[15]1|8[68])))',
     '935' => '(?:(?:8(?:5(?:[01]1|55|3[15])|6(?:01|86))|0492))',
     '936' => '(?:8(?:5(?:36|77|0[127]|[58][58])|6(?:86|0[18])))',
@@ -904,14 +904,14 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|0[1-46])|765)|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|39[2-4]|59[24]|277)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|2(?:19[2-4]|39[24])|4(?:19[2-4]|392)|5(?:49[2-4]|292)|039[23]|8492))',
-    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|0[1-57]|1[0-2489]|5[0-35-9]|7[0-25-79]|4[013-5]|3[0-579]|8[0-35689])|6(?:6[0168]|5[0145]|7[078]|0[1-3568]|1[0-39]|4[01]|2[0-69]|8[016]|3[039])|7(?:5[013589]|3[023578]|0[7-9]|2[0-4]|1[01578]|9[48]|4[0-24-9])|801)|2(?:0(?:8[124-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-8])|29[2-8]|49[258])|0(?:19[23568]|292)|3(?:19[58]|393)))',
+    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|0[1-57]|1[0-2489]|5[0-35-9]|7[0-25-79]|4[013-8]|3[0-579]|8[0-35689])|6(?:6[0168]|5[0145]|7[078]|0[1-3568]|1[0-39]|4[01]|2[0-69]|8[016]|3[039])|7(?:5[013589]|3[023578]|0[7-9]|2[0-4]|1[01578]|9[48]|4[0-24-9])|801)|2(?:0(?:8[124-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-8])|29[2-8]|49[258])|0(?:19[23568]|292)|3(?:19[58]|393)))',
     '951' => '(?:8(?:5(?:3[0136]|4[045]|7[07]|5[0-256]|6[067]|8[01568]|0[1-68]|1[0-24589]|2[0-28])|6(?:01|3[23]|8[056]|5[05]|2[029]|1[0-2]|[67][68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|501)|019[23]))',
     '954' => '(?:(?:86(?:19|86)|019[25]))',
     '955' => '(?:(?:8(?:5(?:43|67|0[135]|5[058]|7[57]|8[589]|1[01])|6(?:66|0[1-3]|7[78]|5[45]|1[126]|8[68])|765)|0192))',
     '956' => '(?:(?:860[1-3]|0192))',
-    '957' => '(?:(?:8(?:5(?:[34]0|11|22|67|5[058]|8[58]|0[236])|6(?:[68]6|01))|0(?:19[237]|293)))',
+    '957' => '(?:(?:8(?:5(?:[34]0|11|22|67|5[058]|8[58]|0[236])|6(?:[68]6|01))|0(?:19[2367]|293)))',
     '958' => '(?:(?:8(?:5(?:01|33|85|5[58])|6(?:01|86))|0292))',
     '959' => '(?:(?:0(?:29[2-6]|19[2-5]|59[235]|39[23]|492)|1(?:29[23568]|39[2357]|69[235]|79[457])|2(?:39[357]|09[23]|292|693|711)|3(?:19[2-46]|49[23]|292|993)|4(?:49[57]|392)))',
     '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|1[1258]|8[014589]|5[058]|6[067]|3[0146]|2[0-4])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
